# ginseng

`ginseng` is a python package for accurate, and somewhat efficient, cell type annotation using [`jax`](https://github.com/jax-ml/jax) and [`zarr`](https://zarr.dev/).

## Installation

`ginseng` can be installed using `pip`

```bash
pip install ginseng
```

Or, added to your project using `uv`

```bash
uv add ginseng
```

## License

`ginseng` is licensed under the MIT License (see LICENSE).

You may not use this file except in compliance with the license. A copy of the license has been included in the root of the repository. Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the MIT license, shall be licensed as above, without any additional terms or conditions.
